==> org-lsst-ccs-config-1.0-sources.jar: org/lsst/ccs/startup/LocalTextToBinary.java <==
package org.lsst.ccs.startup;

import org.lsst.ccs.config.Factories;
import org.lsst.ccs.config.NamesAndTag;
import org.lsst.ccs.config.SubsystemDescription;
import org.lsst.gruth.jutils.ComponentNode;

import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;

/**
 * Utility code to locally transform a description text file to a binary one. A check is performed in the meantime.
 *
 * @author bamade
 */
// Date: 21/06/12

public class LocalTextToBinary {
    public static void main(String[] args) throws Exception {
        if(args.length < 1) {
            System.err.println("usage: java org.lsst.ccs.startup.LocalTextToBinary pathName\n"
                    + " where filename is  xx.groovy or xx.groo\n"
                    + " pathName could be file (with '/' file separator) or resource path");
            System.exit(1);
        }
        String pathName = args[0] ;
        NamesAndTag namesAndTag = BootUtils.namesFromPath(pathName) ;
        InputStream is = BootUtils.getInput(LocalTextToBinary.class, pathName) ;
        SubsystemDescription description = Factories.createRawSubsystemDescription(namesAndTag.getSubsystemName(),
                namesAndTag.getTag(), "", "", is,"ISO-8859-1") ;
        description.check() ;
        ComponentNode componentNode = description.getTopComponentNode() ;
        // opening a new File
        String baseName = BootUtils.baseNameFromNames(namesAndTag) ;
        OutputStream os = new FileOutputStream(baseName+".ser") ;
        ObjectOutputStream oos = new ObjectOutputStream(os) ;
        oos.writeObject(componentNode);
        oos.close() ;
    }
}

==> org-lsst-ccs-config-1.0.10-sources.jar: org/lsst/ccs/startup/LocalTextToBinary.java <==
package org.lsst.ccs.startup;

import org.lsst.ccs.config.utilities.ConfigUtils;
import org.lsst.ccs.config.Factories;
import org.lsst.ccs.config.NamesAndTag;
import org.lsst.ccs.config.SubsystemDescription;
import org.lsst.ccs.utilities.jars.CommonResources;
import org.lsst.gruth.jutils.ComponentNode;

import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;

/**
 * Utility code to locally transform a description text file to a binary one. A check is performed in the meantime.
 *
 * @author bamade
 */
// Date: 21/06/12

public class LocalTextToBinary {
    public static void main(String[] args) throws Exception {
        if(args.length < 1) {
            System.err.println("usage: java org.lsst.ccs.startup.LocalTextToBinary pathName\n"
                    + " where filename is  xx.groovy or xx.groo\n"
                    + " pathName could be file (with '/' file separator) or resource path");
            System.exit(1);
        }
        String pathName = args[0] ;
        NamesAndTag namesAndTag = ConfigUtils.namesFromPath(pathName) ;
        InputStream is = CommonResources.getInput(LocalTextToBinary.class, pathName) ;
        SubsystemDescription description = Factories.createRawSubsystemDescription(namesAndTag.getSubsystemName(),
                namesAndTag.getTag(), "", "", is,"ISO-8859-1") ;
        description.check() ;
        ComponentNode componentNode = description.getTopComponentNode() ;
        // opening a new File
        String baseName = ConfigUtils.baseNameFromNames(namesAndTag) ;
        OutputStream os = new FileOutputStream(baseName+".ser") ;
        ObjectOutputStream oos = new ObjectOutputStream(os) ;
        oos.writeObject(componentNode);
        oos.close() ;
    }
}
